Struct Cr1
#[repr(transparent)]pub struct Cr1(pub u32);Expand description
control register 1.
Tuple Fields
0: u32Implementations
impl Cr1
impl Cr1
pub const fn set_eocalie(&mut self, val: bool)
pub const fn set_eocalie(&mut self, val: bool)
End of calibration interrupt enable.
pub const fn set_jeocie(&mut self, val: bool)
pub const fn set_jeocie(&mut self, val: bool)
Injected end of conversion interrupt enable.
pub const fn set_jovrie(&mut self, val: bool)
pub const fn set_jovrie(&mut self, val: bool)
Injected data overrun interrupt enable.
pub const fn set_reocie(&mut self, val: bool)
pub const fn set_reocie(&mut self, val: bool)
Regular end of conversion interrupt enable.
pub const fn set_rovrie(&mut self, val: bool)
pub const fn set_rovrie(&mut self, val: bool)
Regular data overrun interrupt enable.
pub const fn set_slowck(&mut self, val: bool)
pub const fn set_slowck(&mut self, val: bool)
Slow clock mode enable.
pub const fn set_jdmaen(&mut self, val: bool)
pub const fn set_jdmaen(&mut self, val: bool)
DMA channel enabled to read data for the injected channel group.
pub const fn set_rdmaen(&mut self, val: bool)
pub const fn set_rdmaen(&mut self, val: bool)
DMA channel enabled to read data for the regular channel.